@@ -6,7 +6,7 @@ from .steps import (
     Order,
     Limit,
     Join,
-    Show,
+    Use,
     From,
     Where,
     Map,
